@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2019, kachelaqa <kachelaqa@gmail.com>
+# Copyright (C) 2010-2020, kachelaqa <kachelaqa@gmail.com>
 
 import sys, time
 from PyQt5.QtCore import (
@@ -446,7 +446,7 @@ class Window(QMainWindow, Ui_Window):
                     % exception), 'Abort', 'Critical') is False)
             elif not isinstance(exception, KeyboardInterrupt):
                 details = self.processException(cls, exception, traceback)
-                url = qApp.applicationUrl('issues')
+                url = qApp.applicationUrl('ticket')
                 self._aborting = int(self.messageBox(
                     self.tr('Error'), self.tr(
                     '<br>An unhandled exception occurred.<br>'
@@ -1190,7 +1190,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         self.details.setText(self.tr("""
             <div align="center">
             <p>A utility for browsing pacman databases and the AUR</p>
-            <p>Copyright &copy; 2010-2019, kachelaqa<br>
+            <p>Copyright &copy; 2010-2020, kachelaqa<br>
             &lt;kachelaqa@gmail.com&gt;</p>
             <p><a href="%s">%s</a></p>
             <p>Using:<br>Qt %s<br>Python %s<br>PyQt %s<br>libalpm %s</p>
